==> haskell-concurrent-output-1.10.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.1
id: concurrent-output-1.10.1-2fNed5qAM4M85dHroHf27e
key: concurrent-output-1.10.1-2fNed5qAM4M85dHroHf27e
license: BSD2
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
indefinite: False
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
abi: 41c9a3eec7ee87f154c6a1e85515181d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/concurrent-output-1.10.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/concurrent-output-1.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/concurrent-output-1.10.1
hs-libraries: HSconcurrent-output-1.10.1-2fNed5qAM4M85dHroHf27e
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
    stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw process-1.6.1.0
    directory-1.3.0.2 transformers-0.5.2.0
    exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV
    ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
    terminal-size-0.3.2.1-Hhm9bf6iOprEc6nFG30gJq unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn=2f2bfb87d27ef4e5ac013c6e1a680f92
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=05affb1c34b776a775422ef4ed6b6def
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV=a65573b768f12b6581738ace5752a912
             ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE=de59792f66ffb61bd5cb2ed7de76d387
             terminal-size-0.3.2.1-Hhm9bf6iOprEc6nFG30gJq=9c2997ecb82e5f60ac6a265052a3496b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.10.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.5
id: concurrent-output-1.10.5-C7C4D0AyjaQKDibnXfUCTE
key: concurrent-output-1.10.5-C7C4D0AyjaQKDibnXfUCTE
license: BSD2
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
indefinite: False
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
abi: c54400acdb424de36a9a92e469aa830c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/concurrent-output-1.10.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/concurrent-output-1.10.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/concurrent-output-1.10.5
hs-libraries: HSconcurrent-output-1.10.5-C7C4D0AyjaQKDibnXfUCTE
depends:
    base-4.10.1.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x process-1.6.1.0
    directory-1.3.0.2 transformers-0.5.2.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7
    terminal-size-0.3.2.1-Hhm9bf6iOprEc6nFG30gJq unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=576b92c3ea42677785425376467cda48
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad99cb175fde1a67819ef6519a4015eb
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=eff2744d823431f8209ca0d87f216828
             ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             terminal-size-0.3.2.1-Hhm9bf6iOprEc6nFG30gJq=9c2997ecb82e5f60ac6a265052a3496b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
